@@ -16,7 +16,12 @@ import aws_cdk.core._jsii
 import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("aws-cdk-dynamodb-seeder", "1.44.0", __name__[0:-6], "aws-cdk-dynamodb-seeder@1.44.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "aws-cdk-dynamodb-seeder",
+    "1.56.0",
+    __name__[0:-6],
+    "aws-cdk-dynamodb-seeder@1.56.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
